@@ -54,18 +54,6 @@
 # oldest named release.
 
 RELEASE_MAPPING = {
-    '7.0': {
-        'rpc': '1.40',
-        'objects': {
-            'Node': ['1.21'],
-            'Conductor': ['1.2'],
-            'Chassis': ['1.3'],
-            'Port': ['1.6'],
-            'Portgroup': ['1.3'],
-            'VolumeConnector': ['1.0'],
-            'VolumeTarget': ['1.0'],
-        }
-    },
     '8.0': {
         'rpc': '1.40',
         'objects': {
@@ -128,7 +116,6 @@ RELEASE_MAPPING = {
 #            release (that we are no longer supporting for a rolling upgrade).
 #
 #            There should be at most two named mappings here.
-RELEASE_MAPPING['ocata'] = RELEASE_MAPPING['7.0']
 RELEASE_MAPPING['pike'] = RELEASE_MAPPING['9.1']
 
 # List of available versions with named versions first; 'master' is excluded.
