@@ -359,10 +359,8 @@ def cleanup_cleanwait_timeout(task):
                     "check if the ramdisk responsible for the cleaning is "
                     "running on the node. Failed on step %(step)s.") %
                   {'step': task.node.clean_step})
-    # NOTE(rloo): this is called from the periodic task for cleanwait timeouts,
-    # via the task manager's process_event(). The node has already been moved
-    # to CLEANFAIL, so the error handler doesn't need to set the fail state.
-    cleaning_error_handler(task, msg=last_error, set_fail_state=False)
+    cleaning_error_handler(task, msg=last_error,
+                           set_fail_state=True)
 
 
 def cleaning_error_handler(task, msg, tear_down_cleaning=True,
@@ -395,7 +393,7 @@ def cleaning_error_handler(task, msg, tear_down_cleaning=True,
                    'reason: %(err)s' % {'err': e, 'uuid': node.uuid})
             LOG.exception(msg)
 
-    if set_fail_state and node.provision_state != states.CLEANFAIL:
+    if set_fail_state:
         target_state = states.MANAGEABLE if manual_clean else None
         task.process_event('fail', target_state=target_state)
 
