@@ -208,21 +208,8 @@ class Connection(api.Connection):
 
     def _add_nodes_filters(self, query, filters):
         if filters is None:
-            filters = dict()
-        supported_filters = {'console_enabled', 'maintenance', 'driver',
-                             'resource_class', 'provision_state', 'uuid', 'id',
-                             'chassis_uuid', 'associated', 'reserved',
-                             'reserved_by_any_of', 'provisioned_before',
-                             'inspection_started_before'}
-        unsupported_filters = set(filters).difference(supported_filters)
-        if unsupported_filters:
-            msg = _("SqlAlchemy API does not support "
-                    "filtering by %s") % ', '.join(unsupported_filters)
-            raise ValueError(msg)
-        for field in ['console_enabled', 'maintenance', 'driver',
-                      'resource_class', 'provision_state', 'uuid', 'id']:
-            if field in filters:
-                query = query.filter_by(**{field: filters[field]})
+            filters = []
+
         if 'chassis_uuid' in filters:
             # get_chassis_by_uuid() to raise an exception if the chassis
             # is not found
@@ -241,6 +228,14 @@ class Connection(api.Connection):
         if 'reserved_by_any_of' in filters:
             query = query.filter(models.Node.reservation.in_(
                 filters['reserved_by_any_of']))
+        if 'maintenance' in filters:
+            query = query.filter_by(maintenance=filters['maintenance'])
+        if 'driver' in filters:
+            query = query.filter_by(driver=filters['driver'])
+        if 'resource_class' in filters:
+            query = query.filter_by(resource_class=filters['resource_class'])
+        if 'provision_state' in filters:
+            query = query.filter_by(provision_state=filters['provision_state'])
         if 'provisioned_before' in filters:
             limit = (timeutils.utcnow() -
                      datetime.timedelta(seconds=filters['provisioned_before']))
@@ -250,6 +245,8 @@ class Connection(api.Connection):
                      (datetime.timedelta(
                          seconds=filters['inspection_started_before'])))
             query = query.filter(models.Node.inspection_started_at < limit)
+        if 'console_enabled' in filters:
+            query = query.filter_by(console_enabled=filters['console_enabled'])
 
         return query
 
@@ -1152,9 +1149,25 @@ class Connection(api.Connection):
                 supported_versions = object_versions[model.__name__]
                 if not supported_versions:
                     continue
+
+                # TODO(rloo). Because we forgot to set the version of
+                #     conductors in Pike, we allow the Conductor version to
+                #     be null now (Queens). In Rocky, it cannot be null,
+                #     and this 'if...' can be deleted then.
+                if model.__name__ == 'Conductor':
+                    query = model_query(model.version).filter(
+                        model.version.notin_(supported_versions))
+                    if query.count():
+                        return False
+                    continue
+
+                # NOTE(rloo): we use model.version, not model, because we
+                #             know that the object has a 'version' column
+                #             but we don't know whether the entire object is
+                #             compatible with its (old) DB representation.
                 # NOTE(rloo): .notin_ does not handle null:
                 # http://docs.sqlalchemy.org/en/latest/core/sqlelement.html#sqlalchemy.sql.operators.ColumnOperators.notin_
-                query = model_query(model).filter(
+                query = model_query(model.version).filter(
                     sql.or_(model.version == sql.null(),
                             model.version.notin_(supported_versions)))
                 if query.count():
@@ -1163,13 +1176,20 @@ class Connection(api.Connection):
 
     @oslo_db_api.retry_on_deadlock
     def backfill_version_column(self, context, max_count):
-        """Backfill the version column with Ocata versions.
+        """Backfill the Conductor version column with Pike version.
 
-        The version column was added to all the resource tables in this Pike
+        The version column was added to all the resource tables in the Pike
         release (via 'ironic-dbsync upgrade'). After upgrading (from Ocata to
-        Pike), the 'ironic-dbsync online_data_migrations' command will invoke
-        this method to populate (backfill) the version columns. The version
-        used will be the object version prior to this column being added.
+        Pike), the 'ironic-dbsync online_data_migrations' command would have
+        populated (backfilled) the version column for all objects.
+
+        Unfortunately, in the Pike release, we forgot to set the value for the
+        conductor's version column. For the Queens release, we are setting
+        the conductor version, however, we still need to backfill in case new
+        conductors were added between the time the operator ran Pike's
+        'ironic-dbsync online_data_migrations' and their upgrade to Queens.
+        The version used will be the conductor object version from the Pike
+        release.
 
         :param context: the admin context (not used)
         :param max_count: The maximum number of objects to migrate. Must be
@@ -1178,15 +1198,17 @@ class Connection(api.Connection):
                   migrated (at the beginning of this call) and 2. the number
                   of migrated objects.
         """
-        # TODO(rloo): Delete this in Queens cycle.
-        prior_release = '7.0'
+        # TODO(rloo): Delete this in Rocky cycle.
+        prior_release = 'pike'
         mapping = release_mappings.RELEASE_MAPPING[prior_release]['objects']
         total_to_migrate = 0
         total_migrated = 0
 
-        # backfill only objects that were in the prior release
-        sql_models = [model for model in models.Base.__subclasses__()
-                      if model.__name__ in mapping]
+        # backfill only the Conductor.
+        # NOTE(rloo) This code was used in Pike to backfill all the objects.
+        # To make it easier to review, etc., we are re-using that code with
+        # minimal code changes to only backfill the 'Conductor' object.
+        sql_models = [models.Conductor]
         for model in sql_models:
             query = model_query(model).filter(model.version.is_(None))
             total_to_migrate += query.count()
@@ -1214,6 +1236,9 @@ class Connection(api.Connection):
             num_migrated = 0
             with _session_for_write():
                 query = model_query(model).filter(model.version.is_(None))
+                # NOTE(rloo) Caution here; after doing query.count(), it is
+                #            possible that the value is different in the
+                #            next invocation of the query.
                 if max_to_migrate < query.count():
                     # Only want to update max_to_migrate objects; cannot use
                     # sql's limit(), so we generate a new query with
