@@ -26,7 +26,7 @@ import retrying
 
 from ironic.common import boot_devices
 from ironic.common import exception
-from ironic.common.i18n import _, _LE, _LI, _LW
+from ironic.common.i18n import _
 from ironic.common import states
 from ironic.conductor import rpcapi
 from ironic.conductor import utils as manager_utils
@@ -129,6 +129,10 @@ def _cleaning_reboot(task):
     :param task: a TaskManager instance
     """
     try:
+        # NOTE(fellypefca): Call prepare_ramdisk on ensure that the
+        # baremetal node boots back into the ramdisk after reboot.
+        deploy_opts = deploy_utils.build_agent_options(task.node)
+        task.driver.boot.prepare_ramdisk(task, deploy_opts)
         manager_utils.node_power_action(task, states.REBOOT)
     except Exception as e:
         msg = (_('Reboot requested by clean step %(step)s failed for '
@@ -254,6 +258,11 @@ class HeartbeatMixin(object):
 
         """
 
+    @property
+    def heartbeat_allowed_states(self):
+        """Define node states where heartbeating is allowed"""
+        return (states.DEPLOYWAIT, states.CLEANWAIT)
+
     @METRICS.timer('HeartbeatMixin.heartbeat')
     def heartbeat(self, task, callback_url):
         """Process a heartbeat.
@@ -261,8 +270,14 @@ class HeartbeatMixin(object):
         :param task: task to work with.
         :param callback_url: agent HTTP API URL.
         """
-        # TODO(dtantsur): upgrade lock only if we actually take action other
-        # than updating the last timestamp.
+        # NOTE(pas-ha) immediately skip the rest if nothing to do
+        if task.node.provision_state not in self.heartbeat_allowed_states:
+            LOG.debug('Heartbeat from node %(node)s in unsupported '
+                      'provision state %(state)s, not taking any action.',
+                      {'node': task.node.uuid,
+                       'state': task.node.provision_state})
+            return
+
         task.upgrade_lock()
 
         node = task.node
@@ -270,13 +285,6 @@ class HeartbeatMixin(object):
 
         driver_internal_info = node.driver_internal_info
         driver_internal_info['agent_url'] = callback_url
-
-        # TODO(rloo): 'agent_last_heartbeat' was deprecated since it wasn't
-        # being used so remove that entry if it exists.
-        # Hopefully all nodes will have been updated by Pike, so
-        # we can delete this code then.
-        driver_internal_info.pop('agent_last_heartbeat', None)
-
         node.driver_internal_info = driver_internal_info
         node.save()
 
@@ -302,24 +310,20 @@ class HeartbeatMixin(object):
                 node.touch_provisioning()
             elif node.provision_state == states.CLEANWAIT:
                 node.touch_provisioning()
-                try:
-                    if not node.clean_step:
-                        LOG.debug('Node %s just booted to start cleaning.',
-                                  node.uuid)
-                        msg = _('Node failed to start the first cleaning '
-                                'step.')
-                        # First, cache the clean steps
-                        self.refresh_clean_steps(task)
-                        # Then set/verify node clean steps and start cleaning
-                        manager_utils.set_node_cleaning_steps(task)
-                        _notify_conductor_resume_clean(task)
-                    else:
-                        msg = _('Node failed to check cleaning progress.')
-                        self.continue_cleaning(task)
-                except exception.NoFreeConductorWorker:
-                    # waiting for the next heartbeat, node.last_error and
-                    # logging message is filled already via conductor's hook
-                    pass
+                if not node.clean_step:
+                    LOG.debug('Node %s just booted to start cleaning.',
+                              node.uuid)
+                    msg = _('Node failed to start the first cleaning step.')
+                    # First, cache the clean steps
+                    self.refresh_clean_steps(task)
+                    # Then set/verify node clean steps and start cleaning
+                    manager_utils.set_node_cleaning_steps(task)
+                    # The exceptions from RPC are not possible as we using cast
+                    # here
+                    _notify_conductor_resume_clean(task)
+                else:
+                    msg = _('Node failed to check cleaning progress.')
+                    self.continue_cleaning(task)
 
         except Exception as e:
             err_info = {'node': node.uuid, 'msg': msg, 'e': e}
@@ -462,9 +466,9 @@ class AgentDeployMixin(HeartbeatMixin):
                 # version. Both are operator actions, unlike automated
                 # cleaning. Manual clean steps are not necessarily idempotent
                 # like automated clean steps and can be even longer running.
-                LOG.info(_LI('During manual cleaning, node %(node)s detected '
-                             'a clean version mismatch. Re-executing and '
-                             'continuing from current step %(step)s.'),
+                LOG.info('During manual cleaning, node %(node)s detected '
+                         'a clean version mismatch. Re-executing and '
+                         'continuing from current step %(step)s.',
                          {'node': node.uuid, 'step': node.clean_step})
 
                 driver_internal_info = node.driver_internal_info
@@ -473,10 +477,9 @@ class AgentDeployMixin(HeartbeatMixin):
                 node.save()
             else:
                 # Restart cleaning, agent must have rebooted to new version
-                LOG.info(_LI('During automated cleaning, node %s detected a '
-                             'clean version mismatch. Resetting clean steps '
-                             'and rebooting the node.'),
-                         node.uuid)
+                LOG.info('During automated cleaning, node %s detected a '
+                         'clean version mismatch. Resetting clean steps '
+                         'and rebooting the node.', node.uuid)
                 try:
                     manager_utils.set_node_cleaning_steps(task)
                 except exception.NodeCleaningFailure:
@@ -515,8 +518,8 @@ class AgentDeployMixin(HeartbeatMixin):
                 _cleaning_reboot(task)
                 return
 
-            LOG.info(_LI('Agent on node %s returned cleaning command success, '
-                         'moving to next clean step'), node.uuid)
+            LOG.info('Agent on node %s returned cleaning command success, '
+                     'moving to next clean step', node.uuid)
             _notify_conductor_resume_clean(task)
         else:
             msg = (_('Agent returned unknown status for clean step %(step)s '
@@ -565,13 +568,12 @@ class AgentDeployMixin(HeartbeatMixin):
                     self._client.power_off(node)
                     _wait_until_powered_off(task)
                 except Exception as e:
-                    LOG.warning(
-                        _LW('Failed to soft power off node %(node_uuid)s '
-                            'in at least %(timeout)d seconds. '
-                            'Error: %(error)s'),
-                        {'node_uuid': node.uuid,
-                         'timeout': (wait * (attempts - 1)) / 1000,
-                         'error': e})
+                    LOG.warning('Failed to soft power off node %(node_uuid)s '
+                                'in at least %(timeout)d seconds. '
+                                'Error: %(error)s',
+                                {'node_uuid': node.uuid,
+                                 'timeout': (wait * (attempts - 1)) / 1000,
+                                 'error': e})
                     manager_utils.node_power_action(task, states.POWER_OFF)
             else:
                 # Flush the file system prior to hard rebooting the node
@@ -582,9 +584,9 @@ class AgentDeployMixin(HeartbeatMixin):
                         error = _('The version of the IPA ramdisk used in '
                                   'the deployment do not support the '
                                   'command "sync"')
-                    LOG.warning(_LW(
+                    LOG.warning(
                         'Failed to flush the file system prior to hard '
-                        'rebooting the node %(node)s. Error: %(error)s'),
+                        'rebooting the node %(node)s. Error: %(error)s',
                         {'node': node.uuid, 'error': error})
 
                 manager_utils.node_power_action(task, states.POWER_OFF)
@@ -600,7 +602,7 @@ class AgentDeployMixin(HeartbeatMixin):
             log_and_raise_deployment_error(task, msg)
 
         task.process_event('done')
-        LOG.info(_LI('Deployment to node %s done'), task.node.uuid)
+        LOG.info('Deployment to node %s done', task.node.uuid)
 
     @METRICS.timer('AgentDeployMixin.prepare_instance_to_boot')
     def prepare_instance_to_boot(self, task, root_uuid, efi_sys_uuid):
@@ -621,8 +623,8 @@ class AgentDeployMixin(HeartbeatMixin):
         try:
             task.driver.boot.prepare_instance(task)
         except Exception as e:
-            LOG.error(_LE('Deploy failed for instance %(instance)s. '
-                          'Error: %(error)s'),
+            LOG.error('Deploy failed for instance %(instance)s. '
+                      'Error: %(error)s',
                       {'instance': node.instance_uuid, 'error': e})
             msg = _('Failed to continue agent deployment.')
             log_and_raise_deployment_error(task, msg)
@@ -673,5 +675,4 @@ class AgentDeployMixin(HeartbeatMixin):
                     'error': e})
             log_and_raise_deployment_error(task, msg)
 
-        LOG.info(_LI('Local boot successfully configured for node %s'),
-                 node.uuid)
+        LOG.info('Local boot successfully configured for node %s', node.uuid)
