@@ -97,7 +97,7 @@ class TestGlanceImageService(base.TestCase):
         self.context.project_id = 'fake'
         self.service = service.GlanceImageService(client, 1, self.context)
 
-        self.config(glance_host='localhost', group='glance')
+        self.config(glance_api_servers=['http://localhost'], group='glance')
         try:
             self.config(auth_strategy='keystone', group='glance')
         except Exception:
@@ -156,7 +156,8 @@ class TestGlanceImageService(base.TestCase):
             'properties': {},
             'owner': None,
         }
-        with mock.patch.object(self.service, 'call', return_value=image):
+        with mock.patch.object(self.service, 'call', return_value=image,
+                               autospec=True):
             image_meta = self.service.show(image_id)
             self.service.call.assert_called_once_with('get', image_id)
         self.assertEqual(expected, image_meta)
@@ -164,7 +165,8 @@ class TestGlanceImageService(base.TestCase):
     def test_show_makes_datetimes(self):
         image_id = uuidutils.generate_uuid()
         image = self._make_datetime_fixture()
-        with mock.patch.object(self.service, 'call', return_value=image):
+        with mock.patch.object(self.service, 'call', return_value=image,
+                               autospec=True):
             image_meta = self.service.show(image_id)
             self.service.call.assert_called_once_with('get', image_id)
         self.assertEqual(self.NOW_DATETIME, image_meta['created_at'])
@@ -874,13 +876,6 @@ class TestGlanceAPIServers(base.TestCase):
                                                  service_type='image',
                                                  endpoint_type='public')
 
-    def test__get_api_servers_with_host_port(self):
-        CONF.set_override('glance_host', 'example.com', 'glance')
-        CONF.set_override('glance_port', 42, 'glance')
-        CONF.set_override('glance_protocol', 'https', 'glance')
-        endpoint = service_utils._get_api_server()
-        self.assertEqual('https://example.com:42', endpoint)
-
     def test__get_api_servers_one(self):
         CONF.set_override('glance_api_servers', ['https://10.0.0.1:9293'],
                           'glance')
