@@ -117,17 +117,6 @@ class IscsiDeployMethodsTestCase(db_base.DbTestCase):
             get_image_mb_mock.assert_called_once_with(
                 iscsi_deploy._get_image_file_path(task.node.uuid))
 
-    @mock.patch.object(disk_utils, 'get_image_mb', autospec=True)
-    def test_check_image_size_whole_disk_image(self, get_image_mb_mock):
-        get_image_mb_mock.return_value = 1025
-        with task_manager.acquire(self.context, self.node.uuid,
-                                  shared=False) as task:
-            task.node.instance_info['root_gb'] = 1
-            task.node.driver_internal_info['is_whole_disk_image'] = True
-            # No error for whole disk images
-            iscsi_deploy.check_image_size(task)
-            self.assertFalse(get_image_mb_mock.called)
-
     @mock.patch.object(disk_utils, 'get_image_mb', autospec=True)
     def test_check_image_size_fails(self, get_image_mb_mock):
         get_image_mb_mock.return_value = 1025
@@ -532,7 +521,9 @@ class IscsiDeployMethodsTestCase(db_base.DbTestCase):
                               iscsi_deploy.validate, task)
         mock_get_url.assert_called_once_with()
 
-    def test_validate_invalid_root_device_hints(self):
+    @mock.patch('ironic.drivers.modules.deploy_utils.get_ironic_api_url')
+    def test_validate_invalid_root_device_hints(self, mock_get_url):
+        mock_get_url.return_value = 'http://spam.ham/baremetal'
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
             task.node.properties['root_device'] = {'size': 'not-int'}
