@@ -11,7 +11,6 @@
 #    under the License.
 
 import six
-
 from tempest import config
 from tempest.lib.common.utils import data_utils
 from tempest.lib import decorators
@@ -299,6 +298,19 @@ class TestNodesVif(base.BaseBaremetalTest):
 
         _, self.chassis = self.create_chassis()
         _, self.node = self.create_node(self.chassis['uuid'])
+        if CONF.network.shared_physical_network:
+            self.net = self.os_admin.networks_client.list_networks(
+                name=CONF.compute.fixed_network_name)['networks'][0]
+        else:
+            self.net = self.os_admin.networks_client.\
+                create_network()['network']
+            self.addCleanup(self.os_admin.networks_client.delete_network,
+                            self.net['id'])
+
+        self.nport_id = self.os_admin.ports_client.create_port(
+            network_id=self.net['id'])['port']['id']
+        self.addCleanup(self.os_admin.ports_client.delete_port,
+                        self.nport_id)
 
     @decorators.idempotent_id('a3d319d0-cacb-4e55-a3dc-3fa8b74880f1')
     def test_vif_on_port(self):
@@ -316,13 +328,13 @@ class TestNodesVif(base.BaseBaremetalTest):
             api_microversion_fixture.APIMicroversionFixture('1.28'))
         _, self.port = self.create_port(self.node['uuid'],
                                         data_utils.rand_mac_address())
-        self.client.vif_attach(self.node['uuid'], 'test-vif')
+        self.client.vif_attach(self.node['uuid'], self.nport_id)
         _, body = self.client.vif_list(self.node['uuid'])
-        self.assertEqual({'vifs': [{'id': 'test-vif'}]}, body)
+        self.assertEqual({'vifs': [{'id': self.nport_id}]}, body)
         _, port = self.client.show_port(self.port['uuid'])
-        self.assertEqual('test-vif',
+        self.assertEqual(self.nport_id,
                          port['internal_info']['tenant_vif_port_id'])
-        self.client.vif_detach(self.node['uuid'], 'test-vif')
+        self.client.vif_detach(self.node['uuid'], self.nport_id)
         _, body = self.client.vif_list(self.node['uuid'])
         self.assertEqual({'vifs': []}, body)
         _, port = self.client.show_port(self.port['uuid'])
@@ -355,17 +367,17 @@ class TestNodesVif(base.BaseBaremetalTest):
                   'value': self.portgroup['uuid']}]
         self.client.update_port(self.port['uuid'], patch)
 
-        self.client.vif_attach(self.node['uuid'], 'test-vif')
+        self.client.vif_attach(self.node['uuid'], self.nport_id)
         _, body = self.client.vif_list(self.node['uuid'])
-        self.assertEqual({'vifs': [{'id': 'test-vif'}]}, body)
+        self.assertEqual({'vifs': [{'id': self.nport_id}]}, body)
 
         _, port = self.client.show_port(self.port['uuid'])
         self.assertNotIn('tenant_vif_port_id', port['internal_info'])
         _, portgroup = self.client.show_portgroup(self.portgroup['uuid'])
-        self.assertEqual('test-vif',
+        self.assertEqual(self.nport_id,
                          portgroup['internal_info']['tenant_vif_port_id'])
 
-        self.client.vif_detach(self.node['uuid'], 'test-vif')
+        self.client.vif_detach(self.node['uuid'], self.nport_id)
         _, body = self.client.vif_list(self.node['uuid'])
         self.assertEqual({'vifs': []}, body)
         _, portgroup = self.client.show_portgroup(self.portgroup['uuid'])
@@ -379,13 +391,13 @@ class TestNodesVif(base.BaseBaremetalTest):
                                         data_utils.rand_mac_address())
         patch = [{'path': '/extra/vif_port_id',
                   'op': 'add',
-                  'value': 'test-vif'}]
+                  'value': self.nport_id}]
         self.client.update_port(self.port['uuid'], patch)
 
         _, body = self.client.vif_list(self.node['uuid'])
-        self.assertEqual({'vifs': [{'id': 'test-vif'}]}, body)
+        self.assertEqual({'vifs': [{'id': self.nport_id}]}, body)
 
         self.assertRaises(lib_exc.Conflict, self.client.vif_attach,
-                          self.node['uuid'], 'test-vif')
+                          self.node['uuid'], self.nport_id)
 
-        self.client.vif_detach(self.node['uuid'], 'test-vif')
+        self.client.vif_detach(self.node['uuid'], self.nport_id)
